==> huaweicloudsdkiam-3.1.141-py2.py3-none-any.whl: huaweicloudsdkiam/v5/model/update_login_profile_req_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateLoginProfileReqBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'password': 'str',
        'password_reset_required': 'bool'
    }

    attribute_map = {
        'password': 'password',
        'password_reset_required': 'password_reset_required'
    }

    def __init__(self, password=None, password_reset_required=None):
        """UpdateLoginProfileReqBody

        The model defined in huaweicloud sdk

        :param password: IAM用户的密码。
        :type password: str
        :param password_reset_required: IAM用户下次登录时是否需要修改密码。
        :type password_reset_required: bool
        """
        
        

        self._password = None
        self._password_reset_required = None
        self.discriminator = None

        if password is not None:
            self.password = password
        if password_reset_required is not None:
            self.password_reset_required = password_reset_required

    @property
    def password(self):
        """Gets the password of this UpdateLoginProfileReqBody.

        IAM用户的密码。

        :return: The password of this UpdateLoginProfileReqBody.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this UpdateLoginProfileReqBody.

        IAM用户的密码。

        :param password: The password of this UpdateLoginProfileReqBody.
        :type password: str
        """
        self._password = password

    @property
    def password_reset_required(self):
        """Gets the password_reset_required of this UpdateLoginProfileReqBody.

        IAM用户下次登录时是否需要修改密码。

        :return: The password_reset_required of this UpdateLoginProfileReqBody.
        :rtype: bool
        """
        return self._password_reset_required

    @password_reset_required.setter
    def password_reset_required(self, password_reset_required):
        """Sets the password_reset_required of this UpdateLoginProfileReqBody.

        IAM用户下次登录时是否需要修改密码。

        :param password_reset_required: The password_reset_required of this UpdateLoginProfileReqBody.
        :type password_reset_required: bool
        """
        self._password_reset_required = password_reset_required

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateLoginProfileReqBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.1.152-py2.py3-none-any.whl: huaweicloudsdkiam/v5/model/update_login_profile_req_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateLoginProfileReqBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'password': 'str',
        'password_reset_required': 'bool'
    }

    attribute_map = {
        'password': 'password',
        'password_reset_required': 'password_reset_required'
    }

    def __init__(self, password=None, password_reset_required=None):
        r"""UpdateLoginProfileReqBody

        The model defined in huaweicloud sdk

        :param password: IAM用户的密码。
        :type password: str
        :param password_reset_required: IAM用户下次登录时是否需要修改密码。
        :type password_reset_required: bool
        """
        
        

        self._password = None
        self._password_reset_required = None
        self.discriminator = None

        if password is not None:
            self.password = password
        if password_reset_required is not None:
            self.password_reset_required = password_reset_required

    @property
    def password(self):
        r"""Gets the password of this UpdateLoginProfileReqBody.

        IAM用户的密码。

        :return: The password of this UpdateLoginProfileReqBody.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        r"""Sets the password of this UpdateLoginProfileReqBody.

        IAM用户的密码。

        :param password: The password of this UpdateLoginProfileReqBody.
        :type password: str
        """
        self._password = password

    @property
    def password_reset_required(self):
        r"""Gets the password_reset_required of this UpdateLoginProfileReqBody.

        IAM用户下次登录时是否需要修改密码。

        :return: The password_reset_required of this UpdateLoginProfileReqBody.
        :rtype: bool
        """
        return self._password_reset_required

    @password_reset_required.setter
    def password_reset_required(self, password_reset_required):
        r"""Sets the password_reset_required of this UpdateLoginProfileReqBody.

        IAM用户下次登录时是否需要修改密码。

        :param password_reset_required: The password_reset_required of this UpdateLoginProfileReqBody.
        :type password_reset_required: bool
        """
        self._password_reset_required = password_reset_required

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateLoginProfileReqBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
